#
# spec file for package python3-logilab-common
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-logilab-common
Version:        1.0.2
Release:        4.2
Url:            http://www.logilab.org/projects/common/
Summary:        Python lowlevel functionality shared by logilab projects
License:        LGPL-2.1+
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/l/logilab-common/logilab-common-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-six
BuildArch:      noarch

%description
The package logilab.common contains several modules providing low level
functionalities shared among some python projects developed by logilab.

The package is used by pylint, an advanced Python style and syntax
checker.

Please note that some of the modules have some extra dependencies. For
instance, logilab.common.db will require a db-api 2.0 compliant
database driver.

Please send any comment, patch or question to the python-projects
mailing-list. Before asking a question, please first search the
archives in case it would have already been answered. You may want to
use google and add "site:lists.logilab.org" to your keywords to narrow
your search. We will soon provide our own search engine.

This version is built to use python 3

%prep
%setup -q -n logilab-common-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root="%{buildroot}"
rm -rf %{buildroot}{%{_bindir}/pytest,%{python3_sitelib}/logilab/common/test} # Don't install tests

%files
%defattr(-,root,root)
%doc ChangeLog COPYING COPYING.LESSER README
%{python3_sitelib}/*

%changelog
* Wed Jul 15 2015 arun@gmx.de
- update to version 1.0.2:
  * declare setuptools requirement in __pkginfo__/setup.py
  * randomize order of test modules in pytest -t
- changes from version 1.0.1:
  * restore __pkginfo__.version, which pylint < 1.4.4 uses
* Mon Jul 13 2015 arun@gmx.de
- specfile:
  * update copyright year
  * use setuptools
  * use six, removed 2to3
- update to version 1.0.0:
  * remove unused/deprecated modules: cli, contexts, corbautils, dbf,
    pyro_ext, xmlrpcutils. __pkginfo__ is no longer installed.
  * major layout change
  * use setuptools exclusively
  * 'logilab' is now a proper namespace package
  * modutils: basic support for namespace packages
  * registry: ambiguous selects now raise a specific exception
  * testlib: better support for non-pytest launchers
  * testlib: Tags() now work with py3k
* Thu Dec 18 2014 arun@gmx.de
- update to version 0.63.2: (taken from hg log, no entry in Changelog)
  * pytz is only a setuptools test_require, not an install_requires (closes #281909)
  * fix a bug breaking coverage.py (closes #281908)
  * add missing python3-tz
    build-dependlogilab-common-centos-version-0.63.1-1
    logilab-common-debian-version-0.63.1-1
    logilab-common-version-0.63.1
  * README: remove mention of hg submodule
  * remove deprecated code
- changes from version 0.63.1: (taken from hg log, no entry in Changelog)
  * Fix python3 syntax errors
  * change umask after creating pid file
  * Fix utcdatetime
  * Provides better tools to pause tracing
  * fix TestSuite.run wrapper (closes #280806)
  * write unicode not bytes (closes #277372)
  * fix class_renamed() on old-style classes
  * fix print calls
  * fix for pylint bug #263
  * Update changelog datelogilab-common-centos-version-0.63.0-1 logilab-common-debian-version-0.63.0-1 logilab-common-version-0.63.0
  * fix package and docs build
  * bump debhelper compat level to 8
  * unify packaging
- changes from version 0.63.0:
  * drop compatibility with python <= 2.5 (#264017)
  * fix textutils.py doctests for py3k
  * produce a clearer exception when dot is not installed (#253516)
  * make source python3-compatible (3.3+), without using 2to3.  This
    introduces a dependency on six (#265740)
  * fix umessage header decoding on python 3.3 and newer (#149345)
  * WARNING: the compat module no longer exports 'callable', 'izip', 'imap',
    'chain', 'sum', 'enumerate', 'frozenset', 'reversed', 'sorted', 'max',
    'relpath', 'InheritableSet', or any subprocess-related names.
- changes from version 0.62.1:
  * shellutils: restore py 2.5 compat by removing usage of class decorator
  * pytest: drop broken --coverage option
  * testlib: support for skipping whole test class and conditional skip, don't
    run setUp for skipped tests
  * configuration: load options in config file order (#185648)
* Mon Jul 14 2014 toddrme2178@gmail.com
- Switch link to pypi.  The latest version is not available at the
  old link.
* Thu Jul 10 2014 toddrme2178@gmail.com
- Update to 0.62.0
  * modutils: cleanup_sys_modules returns the list of cleaned modules
* Mon Feb 24 2014 p.drouand@gmail.com
- Do not requires explicitely python3
- Use source from indicated Url
* Sun Feb 23 2014 arun@gmx.de
- update to version 0.61.0, below are the changed taken from Changelog
  * pdf_ext: removed, it had no known users (CVE-2014-1838)
  * shellutils: fix tempfile issue in Execute, and deprecate it
    (CVE-2014-1839)
  * pytest: use 'env' to run the python interpreter
  * graph: ensure output is ordered on node and graph ids (#202314)
* Wed Nov 20 2013 arun@gmx.de
- update to 0.60.0, below are the changes taken from Changelog
- Changes from 0.60.0
  * configuration: rename option_name method into option_attrname (#140667)
  * deprecation: new DeprecationManager class (closes #108205)
  * modutils:
  - fix typo causing name error in python3 / bad message in python2
    (#136037)
  - fix python3.3 crash in file_from_modpath due to implementation
    change of imp.find_module wrt builtin modules (#137244)
  * testlib: use assertCountEqual instead of assertSameElements/assertItemsEqual
    (deprecated), fixing crash with python 3.3 (#144526)
  * graph: use codecs.open avoid crash when writing utf-8 data under python3
    (#155138)
- Changes from 0.59.1
  * graph: added pruning of the recursive search tree for detecting cycles in
    graphs (closes #2469)
  * testlib: check for generators in with_tempdir (closes #117533)
  * registry:
  - select_or_none should not silent ObjectNotFound exception
    (closes #119819)
  - remove 2 accidentally introduced tabs breaking python 3 compat
    (closes #117580)
  * fix umessages test w/ python 3 and LC_ALL=C (closes #119967, report and
    patch by Ian Delaney)
- Changes from 0.59.0
  * registry:
  - introduce RegistrableObject base class, mandatory to make
    classes automatically registrable, and cleanup code
    accordingly
  - introduce objid and objname methods on Registry instead of
    classid function and inlined code plus other refactorings to allow
    arbitrary objects to be registered, provided they inherit from new
    RegistrableInstance class (closes #98742)
  - deprecate usage of leading underscore to skip object registration, using
    __abstract__ explicitly is better and notion of registered object 'name'
    is now somewhat fuzzy
  - use register_all when no registration callback defined (closes #111011)
  * logging_ext: on windows, use colorama to display colored logs, if available (closes #107436)
  * packaging: remove references to ftp at logilab
  * deprecations: really check them
  * packaging: steal spec file from fedora (closes #113099)
  * packaging force python2.6 on rhel5 (closes #113099)
  * packaging Update download and project urls (closes #113099)
  * configuration: enhance merge_options function (closes #113458)
  * decorators: fix @monkeypatch decorator contract for dark corner
    cases such as monkeypatching of a callable instance: no more
    turned into an unbound method, which was broken in python 3 and
    probably not used anywhere (actually closes #104047).
- Changes from 0.58.3
  * date: fix ustrftime() impl. for python3 (closes #82161, patch by Arfrever
    Frehtes Taifersar Arahesis) and encoding detection for python2 (closes
    [#109740])
  * other python3 code and test fixes (closes #104047)
  * registry: Store.setdefault shouldn't raise RegistryNotFound (closes #111010)
  * table: stop encoding to iso-8859-1, use unicode (closes #105847)
  * setup: properly install additional files during build instead of install (closes #104045)
- Changes from 0.58.2
  * modutils: fixes (closes #100757 and #100935)
- Changes from 0.58.1
  * modutils, testlib: be more python implementation independant (closes #99493 and #99627)
* Mon Apr 30 2012 toddrme2178@gmail.com
- Removed tests for unsupported openSUSE versions
* Fri Apr 27 2012 toddrme2178@gmail.com
- Update to version 0.58.0
  * new 'registry' module containing a backport of CubicWeb selectable objects registry (closes #84654)
  * testlib: DocTestCase fix builtins pollution after doctest execution.
  * shellutil: add argument to "ProgressBar.update" to tune cursor progression (closes #88981)
  * deprecated: new DeprecationWrapper class (closes #88942)
- Change license to LGPL 2.1+
* Sat Feb 18 2012 toganm@opensuse.org
- Update to version 0.57.1
  * daemon: change $HOME after dropping privileges (closes #81297)
  * compat: method_type for py3k use instance of the class to
  * have a real instance method (closes: #79268)
* Wed Nov 30 2011 toddrme2178@gmail.com
- Add python 3 package
